pub struct MptProof { /* private fields */ }Expand description
A Merkle Patricia Trie proof for a single key.
Contains an ordered sequence of encoded nodes from the root to the
key’s position. For membership proofs value is Some(v).
For non-membership proofs value is None.
Fields are crate-private to prevent external mutation; use the accessor methods to read them.
Implementations